tail

# XMLRésuméLibrary: User Guide

surname | Element Reference | title

## Name

tail —

Deprecated

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.4.0. It should not be used, and will be removed in a future version.

### Parents

`tail` may be contained in these elements: `docpath`

## Examples

    <!-- TODO -->

surname | Element Reference | title